// package: localapp
// file: localapp.proto

import * as localapp_pb from "./localapp_pb";
import {grpc} from "@improbable-eng/grpc-web";

type LocalAppTunnelStatus = {
  readonly methodName: string;
  readonly service: typeof LocalApp;
  readonly requestStream: false;
  readonly responseStream: true;
  readonly requestType: typeof localapp_pb.TunnelStatusRequest;
  readonly responseType: typeof localapp_pb.TunnelStatusResponse;
};

type LocalAppAutoTunnel = {
  readonly methodName: string;
  readonly service: typeof LocalApp;
  readonly requestStream: false;
  readonly responseStream: false;
  readonly requestType: typeof localapp_pb.AutoTunnelRequest;
  readonly responseType: typeof localapp_pb.AutoTunnelResponse;
};

type LocalAppResolveSSHConnection = {
  readonly methodName: string;
  readonly service: typeof LocalApp;
  readonly requestStream: false;
  readonly responseStream: false;
  readonly requestType: typeof localapp_pb.ResolveSSHConnectionRequest;
  readonly responseType: typeof localapp_pb.ResolveSSHConnectionResponse;
};

export class LocalApp {
  static readonly serviceName: string;
  static readonly TunnelStatus: LocalAppTunnelStatus;
  static readonly AutoTunnel: LocalAppAutoTunnel;
  static readonly ResolveSSHConnection: LocalAppResolveSSHConnection;
}

export type ServiceError = { message: string, code: number; metadata: grpc.Metadata }
export type Status = { details: string, code: number; metadata: grpc.Metadata }

interface UnaryResponse {
  cancel(): void;
}
interface ResponseStream<T> {
  cancel(): void;
  on(type: 'data', handler: (message: T) => void): ResponseStream<T>;
  on(type: 'end', handler: (status?: Status) => void): ResponseStream<T>;
  on(type: 'status', handler: (status: Status) => void): ResponseStream<T>;
}
interface RequestStream<T> {
  write(message: T): RequestStream<T>;
  end(): void;
  cancel(): void;
  on(type: 'end', handler: (status?: Status) => void): RequestStream<T>;
  on(type: 'status', handler: (status: Status) => void): RequestStream<T>;
}
interface BidirectionalStream<ReqT, ResT> {
  write(message: ReqT): BidirectionalStream<ReqT, ResT>;
  end(): void;
  cancel(): void;
  on(type: 'data', handler: (message: ResT) => void): BidirectionalStream<ReqT, ResT>;
  on(type: 'end', handler: (status?: Status) => void): BidirectionalStream<ReqT, ResT>;
  on(type: 'status', handler: (status: Status) => void): BidirectionalStream<ReqT, ResT>;
}

export class LocalAppClient {
  readonly serviceHost: string;

  constructor(serviceHost: string, options?: grpc.RpcOptions);
  tunnelStatus(requestMessage: localapp_pb.TunnelStatusRequest, metadata?: grpc.Metadata): ResponseStream<localapp_pb.TunnelStatusResponse>;
  autoTunnel(
    requestMessage: localapp_pb.AutoTunnelRequest,
    metadata: grpc.Metadata,
    callback: (error: ServiceError|null, responseMessage: localapp_pb.AutoTunnelResponse|null) => void
  ): UnaryResponse;
  autoTunnel(
    requestMessage: localapp_pb.AutoTunnelRequest,
    callback: (error: ServiceError|null, responseMessage: localapp_pb.AutoTunnelResponse|null) => void
  ): UnaryResponse;
  resolveSSHConnection(
    requestMessage: localapp_pb.ResolveSSHConnectionRequest,
    metadata: grpc.Metadata,
    callback: (error: ServiceError|null, responseMessage: localapp_pb.ResolveSSHConnectionResponse|null) => void
  ): UnaryResponse;
  resolveSSHConnection(
    requestMessage: localapp_pb.ResolveSSHConnectionRequest,
    callback: (error: ServiceError|null, responseMessage: localapp_pb.ResolveSSHConnectionResponse|null) => void
  ): UnaryResponse;
}

