// package: localapp
// file: localapp.proto

var localapp_pb = require("./localapp_pb");
var grpc = require("@improbable-eng/grpc-web").grpc;

var LocalApp = (function () {
  function LocalApp() {}
  LocalApp.serviceName = "localapp.LocalApp";
  return LocalApp;
}());

LocalApp.TunnelStatus = {
  methodName: "TunnelStatus",
  service: LocalApp,
  requestStream: false,
  responseStream: true,
  requestType: localapp_pb.TunnelStatusRequest,
  responseType: localapp_pb.TunnelStatusResponse
};

LocalApp.AutoTunnel = {
  methodName: "AutoTunnel",
  service: LocalApp,
  requestStream: false,
  responseStream: false,
  requestType: localapp_pb.AutoTunnelRequest,
  responseType: localapp_pb.AutoTunnelResponse
};

LocalApp.ResolveSSHConnection = {
  methodName: "ResolveSSHConnection",
  service: LocalApp,
  requestStream: false,
  responseStream: false,
  requestType: localapp_pb.ResolveSSHConnectionRequest,
  responseType: localapp_pb.ResolveSSHConnectionResponse
};

exports.LocalApp = LocalApp;

function LocalAppClient(serviceHost, options) {
  this.serviceHost = serviceHost;
  this.options = options || {};
}

LocalAppClient.prototype.tunnelStatus = function tunnelStatus(requestMessage, metadata) {
  var listeners = {
    data: [],
    end: [],
    status: []
  };
  var client = grpc.invoke(LocalApp.TunnelStatus, {
    request: requestMessage,
    host: this.serviceHost,
    metadata: metadata,
    transport: this.options.transport,
    debug: this.options.debug,
    onMessage: function (responseMessage) {
      listeners.data.forEach(function (handler) {
        handler(responseMessage);
      });
    },
    onEnd: function (status, statusMessage, trailers) {
      listeners.status.forEach(function (handler) {
        handler({ code: status, details: statusMessage, metadata: trailers });
      });
      listeners.end.forEach(function (handler) {
        handler({ code: status, details: statusMessage, metadata: trailers });
      });
      listeners = null;
    }
  });
  return {
    on: function (type, handler) {
      listeners[type].push(handler);
      return this;
    },
    cancel: function () {
      listeners = null;
      client.close();
    }
  };
};

LocalAppClient.prototype.autoTunnel = function autoTunnel(requestMessage, metadata, callback) {
  if (arguments.length === 2) {
    callback = arguments[1];
  }
  var client = grpc.unary(LocalApp.AutoTunnel, {
    request: requestMessage,
    host: this.serviceHost,
    metadata: metadata,
    transport: this.options.transport,
    debug: this.options.debug,
    onEnd: function (response) {
      if (callback) {
        if (response.status !== grpc.Code.OK) {
          var err = new Error(response.statusMessage);
          err.code = response.status;
          err.metadata = response.trailers;
          callback(err, null);
        } else {
          callback(null, response.message);
        }
      }
    }
  });
  return {
    cancel: function () {
      callback = null;
      client.close();
    }
  };
};

LocalAppClient.prototype.resolveSSHConnection = function resolveSSHConnection(requestMessage, metadata, callback) {
  if (arguments.length === 2) {
    callback = arguments[1];
  }
  var client = grpc.unary(LocalApp.ResolveSSHConnection, {
    request: requestMessage,
    host: this.serviceHost,
    metadata: metadata,
    transport: this.options.transport,
    debug: this.options.debug,
    onEnd: function (response) {
      if (callback) {
        if (response.status !== grpc.Code.OK) {
          var err = new Error(response.statusMessage);
          err.code = response.status;
          err.metadata = response.trailers;
          callback(err, null);
        } else {
          callback(null, response.message);
        }
      }
    }
  });
  return {
    cancel: function () {
      callback = null;
      client.close();
    }
  };
};

exports.LocalAppClient = LocalAppClient;

